marktools.DirectedMark
======================

.. inheritance-diagram:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark
   :private-bases:

.. autoclass:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.direction

Methods
-------

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__eq__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`
